==> msbackup-1.4.7-py3-none-any.whl: msbackup/encrypt.py <==
# -*- coding: utf-8 -*-
"""Encryption module."""

import os
import subprocess


class Gpg(object):
    """GnuPG encryptor class."""

    SECTION = 'Encrypt-GnuPG'

    def __init__(self, config):
        """
        Class constructor.

        :param config: Config object.
        :type config: :class:`ConfigParser.RawConfigParser`
        """
        self.cmd = config.get(self.SECTION, 'COMMAND', fallback='/usr/bin/gpg')
        self.recipient = config.get(self.SECTION, 'RECIPIENT', fallback=None)
        self.suffix = config.get(self.SECTION, 'SUFFIX', fallback='.gpg')
        self.open = open

    def encrypt(self, source, output=None):
        """
        Encrypt file.

        :param source: Path to file to encrypt.
        :type source: basestring
        :param output: Path to output encrypted file.
        :type output: basestring
        """
        params = [self.cmd, '--quiet', '--batch']
        if output is None:
            output = source + self.suffix
        params.append('--output')
        params.append(output)
        if self.recipient is not None:
            params.append('--recipient')
            params.append(self.recipient)
        else:
            params.append('--default-recipient-self')
        params.append('--encrypt')
        params.append(source)
        with self.open(os.devnull, 'w') as out:
            return subprocess.call(params, stderr=out)


# Encryptors map.
ENCRYPTORS = {
    'none': None,  # Not use encryption.
    'gpg': Gpg,  # Use dnupg encryptor.
}


def make_encryptor(name, config):
    """
    Create encryptor object.

    :param name: Name of encryptor to create.
    :type name: basestring
    :param config: Config object.
    :type config: :class:`ConfigParser.RawConfigParser`
    """
    if name not in ENCRYPTORS:
        raise Exception('Unknown encryptor: {}'.format(name))
    return ENCRYPTORS[name](config)

==> msbackup-1.4.11-py3-none-any.whl: msbackup/encrypt.py <==
# -*- coding: utf-8 -*-
"""Encryption module."""

import subprocess


class Gpg(object):
    """Шифровальщик посредством утилиты GnuPG."""

    SECTION = 'Encrypt-GnuPG'

    def __init__(self, config):
        """
        Конструктор.

        :param config: Конфигурация.
        :type config: :class:`ConfigParser.RawConfigParser`
        """
        self.cmd = config.get(self.SECTION, 'COMMAND', fallback='/usr/bin/gpg')
        self.recipient = config.get(self.SECTION, 'RECIPIENT', fallback=None)
        self.suffix = config.get(self.SECTION, 'SUFFIX', fallback='.gpg')

    def encrypt(self, source, output=None):
        """
        Шифрование файла.

        :param source: Путь к шифруемому файлу.
        :type source: str
        :param output: Путь к зашифрованному файлу.
        :type output: str
        """
        params = [self.cmd, '--quiet', '--batch']
        if output is None:
            output = source + self.suffix
        params.append('--output')
        params.append(output)
        if self.recipient is not None:
            params.append('--recipient')
            params.append(self.recipient)
        else:
            params.append('--default-recipient-self')
        params.append('--encrypt')
        params.append(source)
        subprocess.run(
            params,
            stdout=subprocess.DEVNULL,
            stderr=subprocess.PIPE,
            check=True,
        )


# Encryptors map.
ENCRYPTORS = {
    'none': None,  # Not use encryption.
    'gpg': Gpg,  # Use dnupg encryptor.
}


def make_encryptor(name, config):
    """
    Фабрика шифровальщика.

    :param name: Имя шифровальщика.
    :type name: str
    :param config: Конфигурация.
    :type config: :class:`ConfigParser.RawConfigParser`
    """
    if name not in ENCRYPTORS:
        raise Exception('Unknown encryptor: {}'.format(name))
    return ENCRYPTORS[name](config)
